@@ -72,8 +72,7 @@ int main(int argc, char *argv[])
       switch(p[0]) {
       case 'o':                  /* -o output file */
 	if (argc<=0) {
-	  fprintf(stderr, "No output file specified after -o\n");
-	  usage(arg0);
+	  fprintf(stderr, "No output file specified after -o. See -help for more info.\n");
 	}
 	outfile=*argv;
 	++argv, --argc;
@@ -89,8 +88,7 @@ int main(int argc, char *argv[])
 	usage(arg0);
 	break;
       default: /* invalid option */
-	fprintf(stderr,"Illegal option: -%s\n", p);
-	usage(arg0);
+	fprintf(stderr,"Illegal option: -%s. See -help for more info.\n", p);
 	break;
       }
     } else { /* not an option: must be an input file */
@@ -98,8 +96,7 @@ int main(int argc, char *argv[])
     }
   }
   if (infile==NULL) {
-    fprintf(stderr, "No input file specified\n");
-    usage(arg0);
+    fprintf(stderr, "No input file specified. See -help for more info.\n");
   }
 
   /* done with reading options; syntax seemed okay */
@@ -161,7 +158,7 @@ int main(int argc, char *argv[])
   }
 }
 
-yyerror (char *s)  /* Called by yyparse on error */
+void yyerror (char *s)  /* Called by yyparse on error */
 {
   fprintf(stderr,"%s:%d:  %s\nwhile parsing ... ", 
 	  global_input_file, global_input_line, s);
@@ -170,7 +167,7 @@ yyerror (char *s)  /* Called by yyparse on error */
   global_error=1;
 }
 
-compile_time_err(char *s) {
+void compile_time_err(char *s) {
   fprintf(stderr, "Semantic error: \n");
   yyerror(s);
   exit(1);
@@ -180,14 +177,14 @@ compile_time_err(char *s) {
 char nn_memory[NN][10];
 int nn_next=1;
 
-remember(char *str) {  /* keeps track of the last NN tokens of the input 
+void remember(char *str) {  /* keeps track of the last NN tokens of the input 
 			 stream for use in error messages */
   if (nn_next>=NN) nn_next=0;
   strncpy(nn_memory[nn_next],str,9);
   nn_next++;
 }
 
-print_last_N_tokens(void) {
+void print_last_N_tokens(void) {
   int i=nn_next+1;
   
   do {
@@ -200,7 +197,7 @@ print_last_N_tokens(void) {
 
 int usage(char *p)
 {
-  fprintf(stderr,"Usage: %s [-v[erbose]] [-o outfile] infile\n"
+  fprintf(stdout, "Usage: %s [-v[erbose]] [-o outfile] infile\n"
 	  "       %s -h[elp]\n"
 	  "       infile is - for stdin, outfile is - for stdout.\n", p, p);
   exit(0);
@@ -208,47 +205,9 @@ int usage(char *p)
 
 int help(char *s)
 {
-  fprintf(stderr,
-"The Core Join Calculus is an experimental programming language described in\n"
-"\n"
-"[1] C. Fournet, G. Gonthier.  \n"
-"    The reflexive CHAM and the join-calculus.  To appear in POPL'96.  \n"
-"    http://pauillac.inria.fr/~fournet/papers/popl-96.ps.gz\n"
-"\n"
-"[2] C. Fournet, G. Gonthier, J-J. Levy, L. Maranget, D. Remy. \n"
-"    A Calculus of Mobile Agents.  To appear in CONCUR'96.\n"
-"    http://pauillac.inria.fr/~fournet/papers/concur-96.ps.gz\n"
-"\n"
-"'cjcc' is an experimental compiler of the core join calculus into C.\n"
-"To compile a join calculus file, first use 'cjcc' to generate C code,\n"
-"then use a C-compiler to get an executable file. For example, to compile\n"
-"and run the file 'numbers.j', type\n"
-"\n"
-"        %s -o numbers.c numbers.j\n"
-"        gcc -o numbers numbers.c\n"
-"        numbers\n"
-"\n"
-"Here is a brief summary of the syntax used by cjcc:\n"
-"\n"
-"Values v ::= x | 123 | \"abc\" | true | false | _\n"
-"\n"
-"Processes P ::= x<v1,...,vn>\n"
-"                {}\n"
-"                {P}\n"
-"                P | P\n"
-"                def D in P\n"
-"                def /* name */ D in P\n"
-"\n"
-"Definitions D ::= J --> P\n"
-"                  D and D\n"
-"\n"
-"Join Patterns J ::= x<y1,...,yn>\n"
-"                    J | J         (all yi distinct names)\n"
-"\n"
-"System calls: write <value,continuation,exception>\n"
-"              readint <int_result,exc>\n"
-"              equal <int1,int2,boole_result,exc> similar less\n"
-"              plus <int1,int2,int_result,exc>    similar minus,times,div\n"
-"              if <boole,then_cont,else_cont,exc>\n\n",s);
+  fprintf(stdout,
+          #include "README.sc"
+	  "\n"
+	  );
 }
 
