@@ -7,6 +7,8 @@
    non-terminals from the values of their components. For a
    description of the semantic types, see types.c */
 
+#include <stdlib.h>
+
 char sacc[10000];	/* string accumulator */
 
 processtype empty_process(void)
@@ -530,7 +532,6 @@ definitiontype definition_from_definition_basicdef(in_def, in_bd)
       sprintf(sacc, "Defined variable %s is defined with "
 	      "arities %d and %d in a join pattern",a,n,m);
       compile_time_err(sacc);
-      return;
     }
   }
 
@@ -579,7 +580,6 @@ joinpatterntype jp_from_jp_receiver(in_jp,in_rc)
   if (!disjoint(in_jp.received,in_rc.received)) {
     compile_time_err("Parameters in "
 		     "join patterns are not disjoint");
-    return;
   }
   out_jp.received=append(in_jp.received,listclone(in_rc.received));
   { char *a;
@@ -588,7 +588,6 @@ joinpatterntype jp_from_jp_receiver(in_jp,in_rc)
       sprintf(sacc, "Defined variable %s is defined with "
 	      "arities %d and %d in a join pattern",a,n,m);
       compile_time_err(sacc);
-      return;
     }
   }	
   out_jp.defa=cons(indefa(in_rc.thisdefa),in_jp.defa);
@@ -627,7 +626,6 @@ parameterlisttype pl_from_name_pl(char *in_name, parameterlisttype in_pl)
   if (member(s,in_pl.received)) {
     compile_time_err("Parameters in "
 		     "join patterns are not disjoint");
-    return;
   }
   out_pl.received=cons(s,in_pl.received); 
   out_pl.n=in_pl.n+1;
@@ -651,7 +649,6 @@ sem *program_from_process(processtype in_proc)
     longlistprint(stderr,g);
     fprintf(stderr,"\n");
     compile_time_err("There are undefined global names");
-    return;
   }
 
   code=instr(
@@ -675,7 +672,7 @@ sem *program_from_process(processtype in_proc)
 #include "serverdef.sc"
 		      ));
   code=app(code,in_proc.global);
-  code=app(code,instr(                   "main()\n{\n"
+  code=app(code,instr(                   "int main()\n{\n"
 #include "serverinc.sc"
 		      ));
   code=app(code,in_proc.local);
